布达佩斯大饭店 (豆瓣)
Description: 布达佩斯大饭店电影简介和剧情介绍,布达佩斯大饭店影评、图片、预告片、影讯、论坛、在线购票
Keywords: 布达佩斯大饭店,The Grand Budapest Hotel,布达佩斯大饭店影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.80豆瓣电影Top250

# 布达佩斯大饭店 The Grand Budapest Hotel (2014)

导演: 韦斯·安德森
编剧: 韦斯·安德森 / 雨果·吉尼斯 / 斯蒂芬·茨威格
主演: 拉尔夫·费因斯 / 托尼·雷沃罗利 / 艾德里安·布洛迪 / 威廉·达福 / 裘德·洛 / 爱德华·诺顿 / 西尔莎·罗南 / 蒂尔达·斯文顿 / 比尔·默瑞 / 蕾雅·赛杜 / 欧文·威尔逊 / 詹森·舒瓦兹曼 / 马修·阿马立克 / F·默里·亚伯拉罕 / 汤姆·威尔金森 / 杰夫·高布伦 / 哈威·凯特尔
类型: 剧情 / 喜剧 / 冒险
官方网站: www.grandbudapesthotel.com
制片国家/地区: 美国 / 德国 / 英国
语言: 英语 / 法语 / 德语
上映日期: 2014-02-06(柏林电影节) / 2014-03-28(美国)
片长: 99分钟
又名: 布达佩斯大酒店(港) / 欢迎来到布达佩斯大饭店(台)
IMDb: tt2278388
豆瓣评分
引用
8.9
874612人评价
5星
54.6%
4星
36.3%
3星
8.3%
2星
0.7%
1星
0.2%
好于 99% 喜剧片
好于 98% 剧情片
想看 看过
评价:
推荐

## 布达佩斯大饭店的剧情简介 · · · · · ·

故事要从一位无名作家（裘德·洛 Jude Law 饰）说起，为了专心创作，他来到了名为“布达佩斯”的饭店，在这里，作家遇见了饭店的主人穆斯塔法（F·莫里·亚伯拉罕 F. Murray Abraham 饰），穆斯塔法邀请作家共进晚餐，席间，他向作家讲述了这座饱经风雨的大饭店的前世今生。
饭店曾经的主人名叫古斯塔沃（拉尔夫·费因斯 Ralph Fiennes 饰），而年轻的穆斯塔法（托尼·雷沃罗利 Tony Revolori 饰）在当时不过是追随着他的一介小小门童。古斯塔沃为人正直，精明能干，在他的经营和组织之下，布达佩斯大饭店成为了当时首屈一指的度假胜地。古斯塔沃和年迈的D夫人（蒂尔达·斯文顿 Tilda Swinton 饰）情投意合，D夫人去世后，在遗嘱中将一副价值连城的名画留给了古斯塔沃，这一举动惹恼了她的儿子迪米特里（阿德里安·布洛迪 Adrie... (展开全部) 故事要从一位无名作家（裘德·洛 Jude Law 饰）说起，为了专心创作，他来到了名为“布达佩斯”的饭店，在这里，作家遇见了饭店的主人穆斯塔法（F·莫里·亚伯拉罕 F. Murray Abraham 饰），穆斯塔法邀请作家共进晚餐，席间，他向作家讲述了这座饱经风雨的大饭店的前世今生。
饭店曾经的主人名叫古斯塔沃（拉尔夫·费因斯 Ralph Fiennes 饰），而年轻的穆斯塔法（托尼·雷沃罗利 Tony Revolori 饰）在当时不过是追随着他的一介小小门童。古斯塔沃为人正直，精明能干，在他的经营和组织之下，布达佩斯大饭店成为了当时首屈一指的度假胜地。古斯塔沃和年迈的D夫人（蒂尔达·斯文顿 Tilda Swinton 饰）情投意合，D夫人去世后，在遗嘱中将一副价值连城的名画留给了古斯塔沃，这一举动惹恼了她的儿子迪米特里（阿德里安·布洛迪 Adrien Brody 饰），布达佩斯大饭店和古斯塔沃的厄运就此拉开了帷幕。 ©豆瓣

## 布达佩斯大饭店的演职员 · · · · · · ( 全部 46 )

- 韦斯·安德森 导演
- 拉尔夫·费因斯 饰 古斯塔沃 M. Gustave
- 托尼·雷沃罗利 饰 零 Zero
- 艾德里安·布洛迪 饰 迪米特里 Dmitri
- 威廉·达福 饰 乔普林 Jopling
- 裘德·洛 饰 年轻作家 Young Writer

## 布达佩斯大饭店的视频和图片 · · · · · · ( 预告片22 | 添加视频评论 | 图片2022 · 添加 )

## 布达佩斯大饭店的获奖情况 · · · · · · ( 全部 )

- 第87届奥斯卡金像奖
- 最佳影片(提名)
- 韦斯·安德森 / 杰瑞米·道森 / 史蒂文·M·拉尔斯 / 斯科特·鲁丁

- 第64届柏林国际电影节
- 金熊奖 最佳影片(提名)
- 韦斯·安德森

- 第72届金球奖
- 电影类 最佳音乐/喜剧片

## 喜欢这部电影的人也喜欢 · · · · · ·

  让子弹飞

  大佛普拉斯

  两杆大烟枪

  低俗小说

  荒蛮故事

  一一

  疯狂的石头

  驴得水

  小森林 夏秋篇

  被解救的姜戈

我要写短评

## 布达佩斯大饭店的短评 · · · · · · ( 全部 211313 条 )

热门 / 最新 / 好友

### 5926 有用 Dude 看过 2014-03-17 15:11:41

《布达佩斯大饭店》，配得上太多赞美的词汇，但是电影最后的十几分钟，我内心感到了一股深刻却难以名状的悲伤，想了好久，也想不明白是为什么。走出电影院，感觉就像做了一场梦一样，似乎历历在目，却又难以言说。

### 3892 有用 亵渎电影 看过 2014-06-05 23:20:24

这不仅仅是一部电影，它是游戏，是童话，还是一件艺术品，将作者化的美学风格、形式感和怀旧的主题完美融合！无论从故事、剧作、主题和美学，它的辨识度都只属于自己，对于韦斯·安德森的粉丝，这是杰作！

### 3549 有用 朝阳川生 看过 2014-06-12 20:59:03

故事并不怎么吸引人，完全靠导演的个人风格来博取毫无鉴别力观众的好评。

### 2993 有用 玑衡 看过 2014-03-22 12:05:29

非常好。像一杯温暖的热可可，做得如此甜蜜却又不轻佻，好多台词和段子都有所指涉，却又浑然天成，不像在掉书袋。片尾看到对茨威格的致敬，眼泪都掉下来了。自从好多年前看了Visconti的《豹》之后，这是第二部让我对“昨日的世界”充满向往的电影。

### 2871 有用 唐小万 看过 2014-02-06 23:07:09

依然还是韦斯-安德森标志性的复古色调、悦耳配乐，神经兮兮的冷幽默。不像前作那么随意松散，《大饭店》故事紧凑、层层剥茧，而且居然有点“重口味”。也许只有韦斯-安德森才能把一个混合谋杀、越狱、械斗的故事拍得那么喜感。

> 更多短评 211313条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 布达佩斯大饭店的影评 · · · · · · ( 全部 1505 条 )

热门 / 最新 / 好友
REXT 2014-07-03 19:19:53

## 如果你也翻遍了豆瓣，却找不到一篇干货影评，请戳这里……

这篇影评可能有剧透

首先声明，以下是转载的影评。为什么要转载？因为我能看懂《布达佩斯大饭店》的剧情，却不明白导演想表达什么？能猜出和纳粹有关，可为何犹抱琵琶半遮面，卍字符还要换成两个Z？那么多大牌影星，为何愿意加盟这部荒诞奇葩的作品？为什么非得是布达佩斯的大饭店？如果这些问题得... (展开)
22522 639 897回应 收起
愚公移书 2014-03-29 15:17:57

## （主观臆断）浅谈这部电影和茨威格的联系

影片结尾荧幕上打出"Inspired by Stefan Zweig"(订正：“Inspired by the writings of Stefan Zweig")的时候，好几个看时没细想的地方忽然就觉得很巧妙了。 电影里其实有三个茨威格，其中两个很显然是“作家“，中年和青年时的作家。但这两个顶多只是从身份上的比喻。真正与茨... (展开)
3028 105 126回应 收起
waking王小心 2014-03-27 13:32:30

## 《布达佩斯大饭店》：向逝去的世界致敬

《布达佩斯大饭店》的预告片就是渣。我开始看预告片的时候，还以为电影是一个拼盘杂烩的搞笑喜剧，看简介也是一样。结果发现电影原来是有情节的，于是当成一部侦探剧看了下去；结果发现情节上面是有主题的，于是当成文艺片接着看下去；最后发现不但有文艺，还有政治，还有历史... (展开)
1750 163 94回应 收起
Danny 2014-03-03 10:05:46

## 一出甜蜜的谋杀

一部片子，如果被划分到喜剧片，那么，无论它的内核是多么黑暗，至少尝起来都是甜美可口。 如果把同时期上档的美国骗局比作美式奶昔的话，布达佩斯大饭店，绝对是覆盆子派，松软的派底，玫瑰色的慕斯上铺了满满一层新鲜的覆盆子。是你路过甜品店的橱窗，绝对会回望一眼的尤物... (展开)
945 157 54回应 收起
Ludwigschelle 2015-11-17 05:09:12

## 一个脑残粉的寻迹之旅

其实不能算是影评了，从月升王国开始就是安德森的粉，到了布达佩斯大饭店变成了脑残粉。 于是上周脑残粉利用自己“优越”的地理位置跑去了东德一趟，总算按照剧中提示把能找到的出现在剧中的地方都找了个遍并且整理出了对比照。 其实回到德累斯顿后我还去了Mendl's甜点店的原型... (展开)
1047 4 61回应 收起
艾小柯 2014-04-13 11:16:35

## 一张寄往旧时欧洲的明信片

《布达佩斯大饭店》不是我最喜欢的韦斯·安德森电影，但这并不妨碍它在电影院里夺目的观影体验。 　　 它具有韦氏电影的一切元素：移动长境、暖色调的艳丽布景、精致装潢与服饰、冷幽默、一个了不起的焦点人物、一段或几段令人惊艳的成长关系，还有永恒的Bill Murray。当然，迷... (展开)
786 163 43回应 收起
祥林嫂 2014-03-29 00:07:50

## 不，我只是为了纪念阿加莎，我们曾在这度过一段很美好的时光，虽然很短暂。

我向来只会吐槽一星的电影电视剧，因为我就是个三俗的不行满口脏话的人。 鼓起勇气来写一篇影评给这个：堪称过去12个月里我看过的最赞的电影！但是我发现自己连造句和文法都不太会了！ 想到什么说什么吧： 1. 到电影的最后，一层一层的故事退出来的时候，才发现，原来老夫人们... (展开)
541 42 55回应 收起
LIKE光 2018-09-10 23:13:44 #《布达佩斯大饭店》在韦斯·安德森的作品序列里是什么水准和地位？

## 没有人性没有一切

我觉得截止目前应该是最高水准。 这篇影评我一直都不敢写，因实在太喜欢这部电影，里面任何一个镜头任何一句台词都值得细细品味。导演wes anderson的母亲是一名考古学家，兄弟是大学教授。在良好教育环境下成长的wes anderson不优秀也难，Wes大学选择读哲学，所以Wes的电影中总... (展开)
470 6 20回应 收起
蘑菇精精 2014-03-10 07:08:39

## 战争中的童话故事

患有强迫症的韦斯·安德森把布达佩斯大酒店变成一个7，8岁小女孩儿的粉红色玩具屋。把阿加莎·克里斯蒂的谋杀案变成了神智不清的轻歌剧。把血雨腥风大战前的冰天雪地变成了冬奥会的训练营。把肖生克的救赎变成了四个狐狸爸爸。把神奇的Ralph Fiennes变成了同样神奇的Monsieur G... (展开)
290 31 22回应 收起
木卫二 2014-07-07 13:45:04

## 满怀对世界的爱

如果你不熟悉韦斯·安德森，那么《布达佩斯大饭店》无疑是最适合的一部电影，藉此你可以充分了解他的作品风格。影片大牌群星璀璨，故事行云流水，美术过目难忘，音乐灵动悦耳。而如果你熟悉韦斯·安德森，那么，《布达佩斯大饭店》简直是一次无以伦比的豪华盛筵，一场停不下来... (展开)
263 38 11回应 收起

> 更多影评 1505篇

添加新讨论

## 讨论区 · · · · · ·

在教堂杀手为什么不直接杀掉古斯塔夫和zero而是管家？ | 来自锅包肉太好吃拉 | 2 回应 | 2022-11-21 16:48:44
Agatha 右脸的胎记是...... | 来自小唧唧 | 8 回应 | 2022-11-21 16:47:34
恕我直言，真没觉得这电影有多厉害 | 来自巴鲁和希达 | 299 回应 | 2022-11-20 22:18:32
开头和结尾的钥匙是什么意思 | 来自魿玥 | 5 回应 | 2022-11-19 18:44:01
为什么第二次在火车上被查的时候古斯塔夫给军官看... | 来自精神小妹 | 11 回应 | 2022-11-17 01:18:25

> 去这部影片的讨论区（全部236条）

## 关于《布达佩斯大饭店》的问题 · · · · · · ( 全部135个 )

- 电影中的甜品真的有么？ 20人回答
- zero年老之后为什么变白了？ 32人回答

> 全部135个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 上瘾黑色幽默 (闪正)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 2014新电影（这些，可以期待） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- 别被我ID骗了
  刚刚 看过
- 千层度
  刚刚 看过
- momo
  3分钟前 看过

1279819人看过 / 419390人想看

订阅布达佩斯大饭店的评论:
feed: rss 2.0